summaryrefslogtreecommitdiffstats
path: root/Misc
diff options
context:
space:
mode:
authorBenjamin Peterson <benjamin@python.org>2008-09-17 22:25:09 (GMT)
committerBenjamin Peterson <benjamin@python.org>2008-09-17 22:25:09 (GMT)
commit5478b47355724de2ad891eea469fd8a1e674dccd (patch)
tree069268a8162c6392f681569597f8c39e67910eb0 /Misc
parent357877c8f14f361166b1909bf93a40650d3f5b4c (diff)
downloadcpython-5478b47355724de2ad891eea469fd8a1e674dccd.zip
cpython-5478b47355724de2ad891eea469fd8a1e674dccd.tar.gz
cpython-5478b47355724de2ad891eea469fd8a1e674dccd.tar.bz2
Merged revisions 66457-66459,66465-66468,66483-66485,66487-66491 via svnmerge from
svn+ssh://pythondev@svn.python.org/python/trunk ........ r66457 | antoine.pitrou | 2008-09-13 15:30:30 -0500 (Sat, 13 Sep 2008) | 5 lines Issue #3850: Misc/find_recursionlimit.py was broken. Reviewed by A.M. Kuchling. ........ r66458 | benjamin.peterson | 2008-09-13 17:54:43 -0500 (Sat, 13 Sep 2008) | 1 line fix a name issue; note all doc files should be encoded in utf8 ........ r66459 | benjamin.peterson | 2008-09-14 11:02:22 -0500 (Sun, 14 Sep 2008) | 1 line clarify that radix for int is not 'guessed' ........ r66465 | skip.montanaro | 2008-09-14 21:03:05 -0500 (Sun, 14 Sep 2008) | 3 lines Review usage. Fix a mistake in the new-style class definition. Add a couple new definitions (CPython and virtual machine). ........ r66466 | skip.montanaro | 2008-09-14 21:19:53 -0500 (Sun, 14 Sep 2008) | 2 lines Pick up a few more definitions from the glossary on the wiki. ........ r66467 | benjamin.peterson | 2008-09-14 21:53:23 -0500 (Sun, 14 Sep 2008) | 1 line mention that object.__init__ no longer takes arbitrary args and kwargs ........ r66468 | andrew.kuchling | 2008-09-15 08:08:32 -0500 (Mon, 15 Sep 2008) | 1 line Rewrite item a bit ........ r66483 | georg.brandl | 2008-09-16 05:17:45 -0500 (Tue, 16 Sep 2008) | 2 lines Fix typo. ........ r66484 | benjamin.peterson | 2008-09-16 16:20:28 -0500 (Tue, 16 Sep 2008) | 2 lines be less wordy ........ r66485 | georg.brandl | 2008-09-17 03:45:54 -0500 (Wed, 17 Sep 2008) | 2 lines #3888: add some deprecated modules in whatsnew. ........ r66487 | skip.montanaro | 2008-09-17 06:50:36 -0500 (Wed, 17 Sep 2008) | 2 lines usage ........ r66488 | andrew.kuchling | 2008-09-17 07:57:04 -0500 (Wed, 17 Sep 2008) | 1 line Markup fixes ........ r66489 | andrew.kuchling | 2008-09-17 07:58:22 -0500 (Wed, 17 Sep 2008) | 2 lines Remove comment about improvement: pystone is about the same, and the improvements seem to be difficult to quantify ........ r66490 | andrew.kuchling | 2008-09-17 08:04:53 -0500 (Wed, 17 Sep 2008) | 1 line Note sqlite3 version; move item ........ r66491 | benjamin.peterson | 2008-09-17 16:54:56 -0500 (Wed, 17 Sep 2008) | 1 line document compileall command flags ........
Diffstat (limited to 'Misc')
-rw-r--r--Misc/find_recursionlimit.py29
1 files changed, 21 insertions, 8 deletions
diff --git a/Misc/find_recursionlimit.py b/Misc/find_recursionlimit.py
index 295e094..2e202be 100644
--- a/Misc/find_recursionlimit.py
+++ b/Misc/find_recursionlimit.py
@@ -1,22 +1,32 @@
#! /usr/bin/env python
"""Find the maximum recursion limit that prevents core dumps
This script finds the maximum safe recursion limit on a particular
platform. If you need to change the recursion limit on your system,
this script will tell you a safe upper bound. To use the new limit,
-call sys.setrecursionlimit.
+call sys.setrecursionlimit().
This module implements several ways to create infinite recursion in
Python. Different implementations end up pushing different numbers of
C stack frames, depending on how many calls through Python's abstract
C API occur.
-After each round of tests, it prints a message
-Limit of NNNN is fine.
+After each round of tests, it prints a message:
+"Limit of NNNN is fine".
-It ends when Python causes a segmentation fault because the limit is
-too high. On platforms like Mac and Windows, it should exit with a
-MemoryError.
+The highest printed value of "NNNN" is therefore the highest potentially
+safe limit for your system (which depends on the OS, architecture, but also
+the compilation flags). Please note that it is practically impossible to
+test all possible recursion paths in the interpreter, so the results of
+this test should not be trusted blindly -- although they give a good hint
+of which values are reasonable.
+
+NOTE: When the C stack space allocated by your system is exceeded due
+to excessive recursion, exact behaviour depends on the platform, although
+the interpreter will always fail in a likely brutal way: either a
+segmentation fault, a MemoryError, or just a silent abort.
+
+NB: A program that does not use __methods__ can set a higher limit.
"""
import sys
@@ -87,7 +97,10 @@ def check_limit(n, test_func_name):
test_func = globals()[test_func_name]
try:
test_func()
- except RuntimeError:
+ # AttributeError can be raised because of the way e.g. PyDict_GetItem()
+ # silences all exceptions and returns NULL, which is usually interpreted
+ # as "missing attribute".
+ except (RuntimeError, AttributeError):
pass
else:
print("Yikes!")
@@ -1,22 +1,32 @@
#! /usr/bin/env python
-"""Find the maximum recursion limit that prevents core dumps
+"""Find the maximum recursion limit that prevents interpreter termination.
This script finds the maximum safe recursion limit on a particular
platform. If you need to change the recursion limit on your system,